@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: monad-logger
-version: 0.3.17
-id: monad-logger-0.3.17-5a437bc25b12232eea72a7824921b81a
-key: monad_JUEi2MaKaTzHsqV6vYVXeZ
+version: 0.3.18
+id: monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
+key: monad_1puVRerPS2ZK7jz4Bq78Ve
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/kazu-yamamoto/logger
@@ -16,23 +16,23 @@ exposed: True
 exposed-modules:
     Control.Monad.Logger
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.17
-library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.17
-data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-logger-0.3.17
-hs-libraries: HSmonad-logger-0.3.17-JUEi2MaKaTzHsqV6vYVXeZ
+import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
+library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-logger-0.3.18
+data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-logger-0.3.18
+hs-libraries: HSmonad-logger-0.3.18-1puVRerPS2ZK7jz4Bq78Ve
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
-    conduit-extra-1.1.9.2-fc66bf7a229ea809b0bdda20349fc384
+    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
+    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
-    lifted-base-0.2.3.6-d9ded25fdcc56319fed7ad1fd7194bcc
-    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
+    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
+    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     monad-loops-0.4.3-b8dcb4f8d0b758186f0f7001488f9c96
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
+    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
     stm-chans-3.0.0.4-b9497ea62b3d0161f6f6b1f5b4ed3526
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
